@@ -1,15 +1,23 @@
-from firstimpression.constants import APIS
-from firstimpression.constants import LOCAL_INTEGRATED_FOLDER
-from firstimpression.constants import NAMELEVEL
-from firstimpression.file import update_directories_api
-from firstimpression.file import check_too_old
-from firstimpression.scala import variables
-from firstimpression.scala import log
-from firstimpression.api.request import request_json
 import json
 import os
 import random
 
+from firstimpression.constants import APIS, LOCAL_INTEGRATED_FOLDER
+from firstimpression.file import update_directories_api, check_too_old
+from firstimpression.scala import variables, Log
+from firstimpression.api.request import request_json
+
+##################################################################################################
+# LOGGING
+##################################################################################################
+
+script = 'Chuck Norris (Jokes)'
+
+info = Log('INFO', script)
+debug = Log('DEBUG', script)
+warn = Log('WARN', script)
+error = Log('ERROR', script)
+
 ##################################################################################################
 # CONSTANTS
 ##################################################################################################
@@ -33,24 +41,30 @@ MAX_FILE_AGE = 60 * 60 * 24
 # MAIN FUNCTIONS API
 ##################################################################################################
 
+
 def run_api():
+    debug.log('folder name: {}'.format(NAME))
+    debug.log('file path: {}'.format(JSON_FILE_PATH))
     update_directories_api(NAME)
 
     if check_too_old(JSON_FILE_PATH, MAX_FILE_AGE):
         with open(JSON_FILE_PATH, 'w') as file:
-            json.dump(request_json(URL, params=PARAMS).get('value', [{}]), file)
+            response = request_json(URL, params=PARAMS).get('value', None)
+            if response is None:
+                warn.log('response is empty')
+            else:
+                debug.log(response)
+                json.dump(response, file)
     else:
-        log(NAMELEVEL['INFO'], 'File not old enough to update')
+        debug.log('File not old enough to update')
 
-def check_api():
+
+def check_api(firstname, lastname):
     svars = variables()
 
-    firstname = svars['firstname']
-    lastname = svars['lastname']
-
     if check_too_old(JSON_FILE_PATH, MAX_FILE_AGE):
-       svars['skipscript'] = True
-       log(NAMELEVEL['WARNING'], 'File to old to run chuck_norris')
+        svars['skipscript'] = True
+        debug.log('File to old to run chuck_norris')
     else:
         svars['skipscript'] = False
         svars['joke'] = get_random_joke(firstname, lastname)
